@@ -2,7 +2,7 @@
 #
 # The internetarchive module is a Python/CLI interface to Archive.org.
 #
-# Copyright (C) 2012-2017 Internet Archive
+# Copyright (C) 2012-2019 Internet Archive
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as
@@ -23,7 +23,7 @@ internetarchive.api
 
 This module implements the Internetarchive API.
 
-:copyright: (C) 2012-2017 by Internet Archive.
+:copyright: (C) 2012-2019 by Internet Archive.
 :license: AGPL 3, see LICENSE for more details.
 """
 from __future__ import absolute_import
@@ -447,52 +447,28 @@ def delete(identifier,
 
 
 def get_tasks(identifier=None,
-              task_ids=None,
-              task_type=None,
               params=None,
               config=None,
               config_file=None,
-              verbose=None,
               archive_session=None,
               http_adapter_kwargs=None,
               request_kwargs=None):
-    """Get tasks from the Archive.org catalog. ``internetarchive`` must be configured
-    with your logged-in-* cookies to use this function. If no arguments are provided,
-    all queued tasks for the user will be returned.
+    """Get tasks from the Archive.org catalog.
 
     :type identifier: str
     :param identifier: (optional) The Archive.org identifier for which to retrieve tasks
                        for.
 
-    :type task_ids: int or str
-    :param task_ids: (optional) The task_ids to retrieve from the Archive.org catalog.
-
-    :type task_type: str
-    :param task_type: (optional) The type of tasks to retrieve from the Archive.org
-                      catalog. The types can be either "red" for failed tasks, "blue" for
-                      running tasks, "green" for pending tasks, "brown" for paused tasks,
-                      or "purple" for completed tasks.
-
     :type params: dict
     :param params: (optional) The URL parameters to send with each request sent to the
                    Archive.org catalog API.
 
-    :type config: dict
-    :param secure: (optional) Configuration options for session.
-
-    :type verbose: bool
-    :param verbose: (optional) Set to ``True`` to retrieve verbose information for each
-                    catalog task returned. verbose is set to ``True`` by default.
-
     :returns: A set of :class:`CatalogTask` objects.
     """
     if not archive_session:
         archive_session = get_session(config, config_file, http_adapter_kwargs)
     return archive_session.get_tasks(identifier=identifier,
-                                     task_ids=task_ids,
                                      params=params,
-                                     config=config,
-                                     verbose=verbose,
                                      request_kwargs=request_kwargs)
 
 
@@ -560,7 +536,7 @@ def search_items(query,
                                         max_retries=max_retries)
 
 
-def configure(username=None, password=None, config_file=None):
+def configure(username=None, password=None, config_file=None, host=None):
     """Configure internetarchive with your Archive.org credentials.
 
     :type username: str
@@ -575,7 +551,8 @@ def configure(username=None, password=None, config_file=None):
     """
     username = input('Email address: ') if not username else username
     password = getpass('Password: ') if not password else password
-    config_file_path = config_module.write_config_file(username, password, config_file)
+    config_file_path = config_module.write_config_file(
+        username, password, config_file, host)
     return config_file_path
 
 
