@@ -31,7 +31,6 @@ EXPECTED_S3_HEADERS = {
     'x-archive-queue-derive': '1',
     'x-archive-meta00-scanner': 'uri(Internet%20Archive%20Python%20library',
     'x-archive-size-hint': '7557',
-    'content-md5': '6f1834f5c70c0eabf93dea675ccf90c4',
     'x-archive-auto-make-bucket': '1',
     'authorization': 'LOW a:b',
     'accept': '*/*',
@@ -147,6 +146,7 @@ def test_download_io_error(tmpdir, nasa_item):
     with IaRequestsMock() as rsps:
         rsps.add(responses.GET, DOWNLOAD_URL_RE, body='test content')
         nasa_item.download(files='nasa_meta.xml')
+        rsps.reset()
         with pytest.raises(ConnectionError):
             nasa_item.download(files='nasa_meta.xml')
 
@@ -179,6 +179,7 @@ def test_download_clobber(tmpdir, nasa_item):
         rsps.add(responses.GET, DOWNLOAD_URL_RE, body='test content')
         nasa_item.download(files='nasa_meta.xml')
 
+        rsps.reset()
         rsps.add(responses.GET, DOWNLOAD_URL_RE, body='new test content')
         nasa_item.download(files='nasa_meta.xml')
         load_file('nasa/nasa_meta.xml') == 'new test content'
@@ -200,6 +201,7 @@ def test_download_checksum(tmpdir, caplog):
         assert load_file('nasa/nasa_meta.xml') == 'overwrite based on md5'
 
         # test no overwrite based on checksum.
+        rsps.reset()
         rsps.add(responses.GET, DOWNLOAD_URL_RE,
                  body=load_test_data_file('nasa_meta.xml'))
         nasa_item.download(files='nasa_meta.xml', checksum=True)
@@ -492,6 +494,7 @@ def test_upload_checksum(tmpdir, nasa_item):
 
         _expected_headers = deepcopy(EXPECTED_S3_HEADERS)
         del _expected_headers['x-archive-meta00-scanner']
+        _expected_headers['content-md5'] = '6f1834f5c70c0eabf93dea675ccf90c4'
 
         test_file = os.path.join(str(tmpdir), 'checksum_test.txt')
         with open(test_file, 'wb') as fh:
